==> Fastapi-Mailman-0.0.1.tar.gz: Fastapi-Mailman-0.0.1/fastapi_mailman/backends/file.py <==
"""Email backend that writes messages to a file."""

import datetime
import os

from fastapi_mailman.backends.console import EmailBackend as ConsoleEmailBackend


class ImproperlyConfigured(Exception):
    """Application is somehow improperly configured"""

    pass


class EmailBackend(ConsoleEmailBackend):
    def __init__(self, *args, file_path=None, **kwargs):
        # Since we're using the console-based backend as a base,
        # force the stream to be None, so we don't default to stdout
        kwargs['stream'] = None
        super().__init__(*args, **kwargs)
        self._fname = None
        if file_path is not None:
            self.file_path = file_path
        else:
            self.file_path = self.mailman.file_path
        self.file_path = os.path.abspath(self.file_path)
        try:
            os.makedirs(self.file_path, exist_ok=True)
        except FileExistsError:
            raise ImproperlyConfigured(
                'Path for saving email messages exists, but is not a directory: %s' % self.file_path
            )
        except OSError as err:
            raise ImproperlyConfigured(
                'Could not create directory for saving email messages: %s (%s)' % (self.file_path, err)
            )
        # Make sure that self.file_path is writable.
        if not os.access(self.file_path, os.W_OK):
            raise ImproperlyConfigured('Could not write to directory: %s' % self.file_path)

    def write_message(self, message):
        self.stream.write(message.message().as_bytes() + b'\n')
        self.stream.write(b'-' * 79)
        self.stream.write(b'\n')

    def _get_filename(self):
        """Return a unique file name."""
        if self._fname is None:
            timestamp = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
            fname = "%s-%s.log" % (timestamp, abs(id(self)))
            self._fname = os.path.join(self.file_path, fname)
        return self._fname

    async def open(self):
        if self.stream is None:
            self.stream = open(self._get_filename(), 'ab')
            return True
        return False

    async def close(self):
        try:
            if self.stream is not None:
                self.stream.close()
        finally:
            self.stream = None

==> Fastapi-Mailman-0.0.2.tar.gz: Fastapi-Mailman-0.0.2/fastapi_mailman/backends/file.py <==
"""Email backend that writes messages to a file."""

import datetime
import os
import random

from fastapi_mailman.backends.console import EmailBackend as ConsoleEmailBackend


class ImproperlyConfigured(Exception):
    """Application is somehow improperly configured"""

    pass


class EmailBackend(ConsoleEmailBackend):
    def __init__(self, *args, file_path=None, **kwargs):
        # Since we're using the console-based backend as a base,
        # force the stream to be None, so we don't default to stdout
        kwargs['stream'] = None
        super().__init__(*args, **kwargs)
        self._fname = None
        self.file_path = file_path if file_path is not None else self.mailman.file_path
        self.file_path = os.path.abspath(self.file_path)
        try:
            os.makedirs(self.file_path, exist_ok=True)
        except FileExistsError:
            raise ImproperlyConfigured(
                'Path for saving email messages exists, but is not a directory: %s' % self.file_path
            )
        except OSError as err:
            raise ImproperlyConfigured(
                'Could not create directory for saving email messages: %s (%s)' % (self.file_path, err)
            )
        # Make sure that self.file_path is writable.
        if not os.access(self.file_path, os.W_OK):
            raise ImproperlyConfigured('Could not write to directory: %s' % self.file_path)

    def write_message(self, message):
        self.stream.write(message.message().as_bytes() + b'\n')
        self.stream.write(b'-' * 79)
        self.stream.write(b'\n')

    def _get_filename(self):
        """Return a unique file name."""
        if self._fname is None:
            timestamp = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
            fname = "%s-%s.log" % (timestamp, random.randrange(1e15))
            self._fname = os.path.join(self.file_path, fname)
        return self._fname

    async def open(self): 
        if self.stream is None:
            self.stream = open(self._get_filename(), 'ab')
            return True
        return False

    async def close(self):
        try:
            if self.stream is not None:
                self.stream.close()
        finally:
            self.stream = None
